#include <libps.h>
#include "pad.h"
#include "sound.h"


#define MAIN_VOL (127)
#define SEQ_VOL  (127) 


//--------------------------------------------------------------------------
// Function: InitSoundSys()
// Description: Init sound system. Load in vab and set the main volume
//--------------------------------------------------------------------------

short InitSoundSys(unsigned char *vvh, unsigned char *vvb)
 {  
    short vid;
 	vid = SsVabTransfer(vvh, vvb, -1, 1);
	
	 
	printf("The vab id is  vab:%d\n", vid);
	if( vid < 0 )
	  {
	     printf(" vab:%d", vid);
		 printf(" ERROR: VAB fail (LINE:%d)(FILE:%s)\n",
			      __LINE__,__FILE__);

       }    
  
	// set main volume
	SsSetMVol(MAIN_VOL, MAIN_VOL);
	return(vid);
	
 }// end InitSoundSys


//--------------------------------------------------------------------------
// Function: InitMusic()
//--------------------------------------------------------------------------

short InitMusic(unsigned long *vvs, short vid)
 {  
      short sid;
 	
	// open SEQ, max of 32 SEQ's can be opened at the same time 
	sid = SsSeqOpen(vvs, vid); 	
      printf("The sequence id is %d", sid);
	if( sid < 0 )
	  {
	    printf(" seq:%d", sid);
	    printf(" ERROR: SEQ fail (LINE:%d)(FILE:%s)\n",
			     __LINE__,__FILE__);

       }
	
		
	// set SEQ volume 
	SsSeqSetVol(sid,SEQ_VOL,SEQ_VOL);
      return(sid);

 }// end InitMusic


//--------------------------------------------------------------------------
// Function: SetupReverb()
// Description: Set reverb type, depth, delay and feedback
// Parameters: none
// Returns: none
// Notes: Look at the Library Reference Manual
//--------------------------------------------------------------------------

void SetupReverb( void )
 {

	short type;
	
	// set reverb type
	type = SsUtSetReverbType( SS_REV_TYPE_OFF );

    if( type < 0 )
	    printf(" ERROR: Reverb fail \n");

    // turn on reverb
	SsUtReverbOn();

    // wait awhile
	VSync(0);
	VSync(0);

    // set depth
	SsUtSetReverbDepth(127,127);

	// set delay
	SsUtSetReverbDelay(127);

    // set feedback
	SsUtSetReverbFeedback(127);

 }// SetupReverb



void PlayMusic(short sid )
 {	   
	// read in music and begin playing
	SsSeqPlay(sid, SSPLAY_PLAY, 1);		

 }// end PlaySound





   
//--------------------------------------------------------------------------
// Function: InitSFX()
// Description: Setup our sound effects structure
//--------------------------------------------------------------------------

void InitSFX( voice_data *sound_effect, short va__bid, short program, 
              short tone, short note, short fine, short vol_l, short vol_r )
 {

	sound_effect->vabid   = va__bid;
	sound_effect->program = program;
	sound_effect->tone    = tone;
	sound_effect->note    = note;
	sound_effect->fine    = fine;
	sound_effect->vol_l   = vol_l;
	sound_effect->vol_r   = vol_r; 

 }// end InitSFX

   
   
 
//--------------------------------------------------------------------------
// Function: PlaySFX()
// Description: Play the sound effect
//--------------------------------------------------------------------------

void PlaySFX( voice_data *sound_effect )
 {

	 SsUtKeyOn(sound_effect->vabid,
	       	   sound_effect->program,
			   sound_effect->tone,
			   sound_effect->note,
			   sound_effect->fine,
			   sound_effect->vol_l,
			   sound_effect->vol_r);
	
 }// end PlaySFX


//--------------------------------------------------------------------------
// Function: StopSound()
// Description: Close down the sound system
//--------------------------------------------------------------------------

void StopSoundSys(short vid )
 {
	
	// close vab 
	SsVabClose(vid);

 }// end StopSound
     

//--------------------------------------------------------------------------
// Function: StopMusic()
//--------------------------------------------------------------------------

void StopMusic( short sid )
 {

    // stop SEQ data reading
	SsSeqStop(sid);

    // wait awhile
	VSync(0);
	VSync(0);
	

    // close SEQ data
	SsSeqClose(sid);

 }// end StopMusic

